<?php
//this file must be named cforge_* in order to be seen by transaction template extractor potx

module_load_install('cforge');

/*
 * Cforge .front file, one for each theme
 * runs at the last stage of installation only
 * manages which cforge_* modules are enabled during the installation procedure
 * and all block positions according to the theme
 * and all menu items in specific menus
 */
function cforge_frontend_modules() {
  $modules = array();
  if (db_query("SELECT TRUE FROM {system} WHERE name = 'cforge_hosted'")) {
    //only on the cforge server
    $modules[] = 'cforge_hosted';
  }
  return $modules;
}

function cforge_frontend_theme() {
  return 'sky_seldulac';
}
function cforge_frontend_frontpage() {
  //this is the alias of a node inserted in cforge_frontend_default_content
  return 'home';
}
/*
 * declare all the visible menu items
 * anything not already in that menu will be cloned
 * any path not already in the menu_router will be ignored
 * any path without a title will use its existing title.
 *
 */
function cf_frontend_menu() {
  $positions = array(
    'user-menu' => array(
      //'user',//added automatically
      'transact/1stparty',
      'transact/3rdparty',
      'node/add/offer',
      'node/add/want',
      'node/add',
      'admin/people',
      'admin/content',
      'admin/structure/taxonomy/galleries',
      'admin/config/system/backup_migrate/export',
      'hamlets_helpdesk',
      //'user/logout'//added automatically
    ),
    'secondary-menu' => array(
      db_query("SELECT source FROM url_alias where alias = 'faq'")->fetchField(),//drupal_lookup_path is too language dependent
      'contact',
      'galleries',
      'events-all',
    ),
    //put things things here to hide them
    'navigation' => array(),
    'setup' => array(
      'admin/modules',
      'admin/config/system/site-information',
      'admin/appearance/settings/sky_seldulac',
      'admin/config/people/accounts',
      'admin/config/ow',
      'admin/structure/taxonomy',
      'admin/structure/block',
      'admin/structure/menu/manage/main-menu',
      'admin/structure/menu/manage/secondary-menu',
      'admin/structure/menu/manage/visitors',
      'admin/structure/contact',
      'admin/config/cforge',
      'admin/people/launch',
       BACKUP_MIGRATE_MENU_PATH
    ),
    //the visitors menu is not declared here because all the links are placed there by nodes
  );
  drupal_load('module', 'mcapi');
  $currencies = currencies_load();
  foreach (array_keys($currencies) as $currcode) {
    $currs[] = 'admin/accounting/currencies/list/'.$currcode.'/edit';
  }
  array_splice($positions['setup'], 5, 0, $currs);
  return $positions;
}

//expected function
//unfortunately potx module ignores this file, and I can't think how to get the menu names and descriptions elsewhere
function cforge_frontend_menus() {
  $all_menus = menu_get_menus();
  //add the custom menus
  $custom_menus[] = array(
    'menu_name' => 'visitors',
    'title' => t("Visitor menu"),
    'description' => t('For visitors who are not logged in')
  );
  $custom_menus[] = array(
    'menu_name' => 'secondary-menu',//this is because that's how it worked in Drupal6
    'title' => t('Secondary links menu'),
    'description' => t('Less prominent links, for all users')
  );
  foreach ($custom_menus as $info) {
    if (!isset($all_menus[$info['menu_name']])) {
      menu_save($info);
    }
  }
  variable_set('menu_secondary_links_source', 'secondary-menu');//as in cforge for d6
  variable_set('menu_main_links_source', 'main-menu');
}


/**
 * specify the blocks in the cforge_* modules
 * have to check for the presence of each block in case it's module is not enabled
 */
function cforge_block_positions() {
  // This structure isn't perfect but assumes that there are no delta duplicates per region.
  $placements = array(
    'navigation' => array(
      'main-menu' => 'system',
      'visitors' => 'menu'
    ),
    'headerright' => array(
      'secondary-menu' => 'menu',
    ),
    'help' => array(
      'help' => 'system',
    ),
    'content' => array(
      'main' => 'system'
    ),
    'sidebar_first' => array(
      'masquerade' => 'masquerade',
      'propositions_taxonomy_block' => 'offers_wants',
      'add_proposition' => 'offers_wants',
      'feed-2'=> 'aggregator',
      'calendar-block_1' => 'views',
      'ow_wants-urgent' => 'views',
      'ow_wants-latest' => 'views',
      'ow_offers-latest' => 'views',
      '1stparty' => 'mcapi_forms',
      'transactions-who_gave_what' => 'views',
      'feed-1'=> 'aggregator',
      'new' => 'user',
    ),
    'sidebar_second' => array(
      'user-menu' => 'system',
      'setup' => 'menu',
      'waiting_on_uid' => 'mcapi_signatures',
      'login' => 'user',
      'comments_recent-block' => 'views',
      'random_photo' => 'cforge_gallery',
      'nitin' => 'cforge',
      'sel_promo' => 'cforge',
      'decouvrir' => 'cforge',
      'cf_training' => 'cforge'
    ),
    'contentbottom' =>array(
      'user_pending' => 'mcapi_signatures'
    ),
    'footer' => array(
      'trade_analysis-system' => 'views'
    ),
  );
  if (module_exists('search')) {
    $placements['headerright']['form'] = 'search';
  }
  return $placements;
}


function cforge_frontend_default_nodes() {
  $lang = language_default('language') == 'en' ? LANGUAGE_NONE : language_default('language');

  cf_setup_rss();

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('Home'),
    'body' => array (
      'und' => array (
        0 => array (
          'value' => '<p><p>This is your new public front page!</p>
<p>What do site visitors need to know about your community?</p>
<ul>
	<li>Next public meeting?</li>
	<li>How to join?</li>
	<li>Partner organisations?</li>
	<li>What you have achieved for the wider community?</li>
	<li>Why you exist?</li>
</ul>',
          'format' => 'full_html',
        ),
      ),
      'fr' => array(
        0 => array(
          'value' => '<p><img src="/profiles/cforge/money-go-round.gif" style="float: right;" /></p>
<p>SEL veut dire «Système d&apos;Echange Local».</p>
<p>C&apos;est une association dont les membres échangent entre eux des Services, des Savoirs et des biens.</p>
<p>Les échanges sont mesurés dans une unité autre que l&apos;argent, les XXXX, dans le désir d&apos;évoluer vers plus de citoyenneté et de solidarité.</p>
<p>Pour certains, le SEL permet de suivre un cours, de donner un coup de main ou de donner une autre vie à des objets dans un cadre convivial sans toucher à son porte-monnaie.</p>
<p>Pour d&apos;autres, le SEL répond à un choix de vie, une envie de se positionner, de résister au système dominant.&nbsp;</p>
<p><a href="/share">Commencez par vous informer&gt;</a></p>',
         'format' => 'full_html',
        )
      )
    ),
    'path' => array (
      'alias' => 'home',
    ),
    'menu' => array (
      'link_title' => t('Home'),
      'description' => '',
      'menu_name' => 'visitors',
      'module' => 'menu',
      'weight' => '1',
      'enabled' => true,
    ),
  );

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('Share'),
    'body' => array (
      'und' => array (
        0 => array (
          'value' => '<strong>Join us and share </strong>
<p>The local exchange systems gives you many opportunities to share.
<p><strong>Put your new members information here</strong>
<p>Background, information, directions, times, locations.
<p><strong>Share collective tasks</strong>
<p>Each association is only the sum of the actions of its members. That is why it is important to share the tasks related to the proper functioning thereof. The heading "Tasks" facilitates and encourages their distribution. Some tasks for the association may be paid in time or units. Solidarity contributions gain LETS for payment.
<p><strong> <a href="/start"> Share your knowledge, your property - Exchange </a> </strong>',
          'format' => 'full_html',
        ),
      ),
      'fr' => array (
        0 => array (
          'value' => '<p><strong>Pour changer, partageons!</strong></p>
<p>Nos membres se découvrent beaucoup plus « riches » grâce aux échanges qu&apos;ils effectuent. La vraie richesse est constituée par les savoirs et services que les membres sont capables de créer, d&apos;offrir, de demander et non par ce que le marché décide de nous fournir.</p>
<p><strong>Comment ça marche ?</strong></p>
<p>Les Offres et Demandes paraissent sur notre site et/ou sur un catalogue. Un membre prend contact avec un(e) autre membre pour faire un échange. Les membres s&apos;accordent sur sa valeur&nbsp;et font l&apos;échange.</p>
<p>Ensuite,</p>
<p>- soit un(e) des membres encode l&apos;échange sur le site et son partenaire confirme l&apos;échange en ligne,</p>
<p>- soit les deux membres signent leur témoin d&apos;échange (document papier).&nbsp;</p>
<p><strong>Les Offres</strong></p>
<p>Envie de partager une passion? Tant de personnes ont des talents, des compétences aucunement valorisés par le marché : grand-mères spécialistes en dentelles, grands-pères merveilleux conteurs d&apos;histoires, mères de famille couturières ou cuisinières émérites, personnes handicapées avec talents artistiques, etc., la liste est longue ! <a href="/offers">voir les Offres &gt;</a></p>
<p><strong>Les Demandes</strong></p>
<p>Grâce au système SEL, chacun découvre des personnes qui ont justement besoin du service qu&apos;il (elle) est capable d&apos;offrir, et cela au moment opportun qui ne correspond que rarement à un horaire de bureau ou d&apos;usine. Outre le plaisir de pouvoir s&apos;échanger ces services, certaines personnes qui avaient coutume de se sous-estimer, s&apos;en trouvent valorisées.&nbsp;<a href="/wants">voir les Demandes &gt;</a></p>
<p><strong>Vous manquez d&apos;idées ? </strong></p>
<p>Vous n&apos;imaginez pas encore ce que vous pourriez offrir en échange des services qui pourraient vous être utiles ?</p>
<p>Nous sommes tous passés par là !</p>
<p>Pour vous aider à trouver des pistes, nous pouvons en parler ensemble.</p>
<p>Nous disposons aussi d&apos;une liste de catégories de services.</p>
<p>En la parcourant, il devient évident qu&apos;<strong><em>on a tous quelque chose à partager</em></strong>.</p>
<p>Vous êtes prêts? <a href="/start">Comment commencer ?</a></p>',
          'format' => 'full_html',
        ),
      ),
    ),
    'path' => array (
      'alias' => 'share',
    ),
    'menu' => array (
      'link_title' => t('Share'),
      'description' => '',
      'menu_name' => 'visitors',
      'module' => 'menu',
      'weight' => '2',
      'enabled' => true,
    ),
  );

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('Getting started'),
    'body' => array (
      'und' => array (
        0 => array (
          'value' => '<p>Nous vous proposons plusieurs pistes pour faire connaissance avec les <strong>S</strong>ystèmes d&apos;<strong>E</strong>changes&nbsp;<strong>L</strong>ocaux.</p>
<p><a href="/lets">La page consacrée aux&nbsp;<strong>SELs</strong></a>, vous permettra de découvrir comment fonctionne un Système d&apos;Echange Local&nbsp;mais aussi d&apos;aller à la rencontre d&apos;autres SELs.</p>
<p><a href="/faq">La page de la <strong>Foire aux questions</strong></a>&nbsp;vous familiarisera avec les fonctionnalités que nous utilisons dans le site.&nbsp;</p>
<p>Toutes ces pages sont accessibles en cliquant sur le "lien" (la phrase soulignée et en couleur) dans le texte ci-dessus ou bien sur les mots "SELs", et "FAQ" en haut à droite de votre écran.</p>
<p>Maintenant que vous avez découvert les coulisses de votre SEL, <a href="/share">commençons à partager&gt;</a>.</p>',
          'format' => 'full_html',
        ),
      ),
      'fr' => array (
        0 => array (
          'value' => '<strong>Pour changer, échangeons!</strong>
<p>Nos membres se découvrent beaucoup plus « riches » grâce aux échanges qu\'ils effectuent, puisque la vraie richesse est constituée par les biens et services que les membres sont capables de créer ou d’offrir, et non par ce que le marché veut bien offrir.
<p><strong>Comment ça marche ?</strong>
Les Offres et Demandes paraissent sur notre site, ou sur catalogue. Un membre prend contact avec une autre membre pour faire un échange. Les membres s’accordent sur sa valeur en « grains de sel », et font l’échange. Ensuite, un-e des membres saisit l\'échange sur le site, l\'autre le confirme et voilà l\'échange est comptabilisé.
<p><strong>Les Offres</strong>
Envie de partager une passion?  Tant de personnes ont des talents, des compétences aucunement valorisés par le marché : grand-mères spécialistes en dentelles, mères de famille couturières ou cuisinières émérites, personnes handicapées avec talents artistiques, etc., la liste est longue ! <a href="/offers">voir les Offres></a>
<p><strong>Les Demandes</strong>
Grâce au système SEL, elles découvrent soudain des personnes qui ont justement besoin du service qu’elles sont capables d’offrir, et cela au moment opportun pour elles, qui ne correspond que rarement à un horaire de bureau ou d’usine. Ces personnes, souvent modestes, qui avaient coutume de se sous-estimer, s’en trouvent valorisées.  <a href="/wants">voir les Demandes></a>
<p><strong><a href="/commit">Échanger, c&apos;est S&apos;engager></a></strong>',
          'format' => 'full_html',
        ),
      ),
    ),
    'path' => array (
      'alias' => 'start',
    ),
    'menu' => array (
      'link_title' => t('Getting started'),
      'description' => '',
      'menu_name' => 'visitors',
      'module' => 'menu',
      'weight' => '3',
      'enabled' => true,
    ),
  );

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('Commit!'),
    'body' => array (
      'und' => array (
        0 => array (
          'value' => '<strong>Example: To become a member of LETS </strong>
<ol><li>Browse our site to better understand the system.</li>
<li>Contact members/attend orientation meeting, put information here.</li>
<li>Filling out registration form, put link to form here.</li>
<li>Fee to pay, how much, where/who/how to pay information here.</li>
<li>Details of how the process continues after payment.</li>
<li>Welcome to the LETS. To share and enrich you!</li></ol>',
          'format' => 'full_html',
        ),
      ),
      'fr' => array (
        0 => array (
          'value' => '<p><strong>Marche à suivre pour devenir membre du SEL</strong></p>
<p>1. Vous informer:</p>
<ul>
	<li>Soit en parcourant notre site pour mieux comprendre les <a href="sel">SELs </a>et les <a href="/faq">questions fréquemment posées</a>.</li>
	<li>Soit en demandant un exemplaire papier de ces documents pour les consulter à votre aise chez vous.</li>
	<li>Soit en rencontrant un des responsables de votre SEL..</li>
</ul>
<p>2. Participer à une rencontre de votre SEL.</p>
<p class="rteindent1">Vous aurez ainsi l&apos;occasion de rencontrer d&apos;autres membres qui vous présentront le SEL et à qui vous pourrez poser toutes les&nbsp;questions nécessaires à une bonne compréhension.</p>
<p class="rteindent1" dir="ltr">Pour connaître le jour et le lieu de la prochaine réunion, <a href="/contact">contactez-nous</a>.</p>
<p>3. Une fois que vous avez assisté à cette présentation, vous pourrez devenir membre</p>
<ul>
	<li>en remplissant votre fiche d&apos;inscription</li>
	<li>en payant votre inscription (si votre communauté demande une petite participation financière)</li>
	<li>en commençant à proposer vos offres ou demandes</li>
</ul>
<p>4. Rapidement, un responsable&nbsp;vous communiquera votre numéro de membre. Si vous avez décidé de fonctionner via un ordinateur, vous recevrez aussi votre mot de passe. Il vous sera alors possible d&apos;accéder à la partie du site réservée aux membres.</p>
<p>Bienvenue dans le SEL!</p>
<p>Échangez et vous vous enrichirez !</p>',
          'format' => 'full_html',
        ),
      ),
    ),
    'path' =>array (
      'alias' => 'commit',
    ),
    'menu' => array (
      'link_title' => t('Commit!'),
      'description' => '',
      'menu_name' => 'visitors',
      'module' => 'menu',
      'weight' => '4',
      'enabled' => true,
    ),
  );

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('FAQ'),
    'body' => array (
      'und' => array (
        0 => array (
          'value' => '<p><strong>What is the unit of account</strong>?</p>
<p>Each community defines its own unit of account, giving it both a name and a value. The name is often a local reference or pun. The reference is usually to time e.g 10 minutes, but could be to the national currency. Time banks have an egalitarian convention that their currency is in hours and everyone&apos;s hour is worth one hour.</p>
<p><strong>Isn&apos;t this barter?</strong></p>
<p><em>Barter</em> has different meanings according to context. It can mean price negotiation, or simply swapping one thing for another of equivalent value. However when conducted between multiple parties, barter is greatly assisted by a unit of account and a record of transactions.</p>
<p><strong>What&apos;s the difference between your unit of account and national money</strong></p>
<p>There are some very important differences. National money is treated as a commodity, which means it bears interest when lent, and you must have some before you can spend it. In mutual credit systems the unit of account represents a short term interest-free credit which (usually) anyone can access. There is neither stigma nor penalty for having a balance below zero - in fact it is necessary that all the positive credit is &apos;balanced&apos; by negative credit. As long as members commit to closing their accounts with the same amount they started with, 0, everything works! Local money can only be spent within the participating community, in contrast to national money, which we are forced to accept by the law of the land!</p>
<p><strong>I don&apos;t want to be in debt!</strong></p>
<p>This debt isn&apos;t like debt in national money because there is no time-value of the &apos;money&apos; (interest), and there has to be an equal and opposite negative balance for every positive balance. If you finish a race neck and neck, it doesn&apos;t matter who was ahead and who was behind during the race. What matters is that you close your account on zero, and that others believe you intend to do so!</p>
<p><strong>What if someone dies or leaves not on zero</strong></p>
<p>The system can absorb some losses (or gains) without anyone noticing. Usually the losses and gains approximately cancel each other out. If they don&apos;t then some kind of tax (or giveaway) might be needed to prevent inflation, or deflation.</p>
<p><strong>Why not give things away for free?</strong></p>
<p>We agree! However many people are confident that if they give, they will receive. Keeping accounts gives many people the confidence to ask for what they need. Some people stop recording their transactions after a while. This means that the system is working! However it is helpful for everyone to see the value being created in the community. For this reason some communities allow transactions to be recorded with a value of 0! <strong> </strong></p>
<p><strong>What guarantee is there on the quality of goods or services offered?</strong></p>
<p>None. But many people are motivated to please because of their reputation in the community.</p>
<p><strong>Free software? No ads? No spying?</strong></p>
<p>Yes! In Community Forge we believe that the best things in life are free, and we&apos;ve invested many thousands of hours to bring you this free community portal, and free hosting. You can help to keep it free by making a donation to pay our monetary expenses (not wages). Please see http://communityforge.net/en/donate</p>',
          'format' => 'full_html',
        ),
      ),
      'fr' => array (
        0 => array (
          'value' => '<h3>Lexique</h3>
<h5>Qu\'est-ce qu\'un échange "à confirmer"?</h5>
<p>C\'est un échange en attente de confirmation de votre partenaire.</p>
<h5>Qu\'est-ce qu\'un échange "comptabilisé"?</h5>
<p>C\'est un échange confirmé, qui a été débité/crédité dans les comptes respectifs.</p>
<h5>C\'est quoi les Soldes?</h5>
<p>Le "Solde" représente le total des unités (en positif) échangés depuis la mise en place du site. En d\'autres mots, c\'est la richesse que vous avez créée.</p>
<h5>Vocabulaire SELs</h5>
<p>Les SELS évitent le vocabulaire financier car il ne faut pas confondre les deux systèmes!</p>
<ul>
<li>à la place de « chèque », utilisez « bon d’échange » ou « unités d’échange »</li>
<li>évitez aussi « vendre » et « acheter » : on « donne », « offre », « échange », « propose », « reçoit »</li>
<li>parlez d’« échange » plutôt que de « transaction ».</li>
<li>parlez de « service » que vous rendez à quelqu’un qui en a besoin, de « richesse » que vous apportez ou recevez.</li>
</ul>
<h3>Votre Compte</h3>
<h5>Comment accéder à mon compte?</h5>
<p>Cliquez sur le lien "Mon compte" en dessous de votre nom (en haut à droite).</p>
<h5>Comment changer mon email / mot de passe?</h5>
<p>Cliquez sur le lien "Mon compte" en dessous de votre nom (en haut à droite) &gt; Cliquez sur l\'onglet "Paramètres" &gt; N\'oubliez pas de cliquer sur "Enregistrer" au bas de la page.</p>
<h5>Comment changer mon adresse?</h5>
<p>Cliquez sur le lien "Mon compte" en dessous de votre nom (en haut à droite) &gt; Cliquez sur l\'onglet "Mes infos" &gt; N\'oubliez pas de cliquer sur "Enregistrer" au bas de la page.</p>
<h5>Comment consulter la liste de Mes Echanges?</h5>
<p>Cliquez sur le lien "Mon compte" en dessous de votre nom (en haut à droite) &gt; Cliquez sur l\'onglet "Echanges".</p>
<h5>Comment consulter la liste de Mes Offres et demandes?</h5>
<p>Cliquez sur le lien "Mon compte" en dessous de votre nom (en haut à droite) &gt; Cliquez sur l\'onglet "Offres et demandes".</p>
<h3>Offres &amp; Demandes</h3>
<h5><span style="line-height: 1.2em; font-size: 13px;">Comment ajouter une Offre/Demande?</span></h5>
<p>Cliquez sur le lien "Enregistrer l\'offre" ou "Enregistrer la demande" en dessous de votre nom (en haut à droite).</p>
<h3>Membres</h3>
<h5>Comment contacter un membre ?</h5>
<p>Cliquez sur "Membres" dans le menu du haut &gt; Cliquez sur le numéro du membre: dans le profil du membre, vous avez directement accès à son adresse postale et à son numéro de téléphone.</p>
<h5>Comment envoyer un email à un membre ?</h5>
<p>Cliquez sur "Membres" dans le menu du haut &gt; Cliquez sur le numéro du membre&nbsp;&gt; Cliquez sur l\'onglet "Contact".<br />
Nous avons choisi cette méthode pour faciliter la prise de contact mais éviter l\'abus des emails.</p>
<h3>Échanges</h3>
<h5>Comment Ajouter un Échange?</h5>
<p>Cliquez sur le lien "Saisir un échange" en dessous de votre nom (en haut à droite). Vous avez également la possibilité d\'aller sur le compte d\'un membre et d\'utiliser le formulaire sur la gauche.</p>
<h5>Qui saisit l\'échange sur le site?</h5>
<p>Généralement la personne qui va verser des unités, ou selon accord. Ce qui est important est que vous contrôliez vos échanges "à confirmer" avant de faire la saisie d\'un nouvel échange, pour éviter des doublons. Tant que votre partenaire n\'as pas confirmé l\'échange, vous pouvez le modifier ou le supprimer.</p>
<h5>Que faire si le partenaire n\'a pas confirmé l\'échange?</h5>
<p>D\'abord, faire preuve d\'un peu de patience. Certaines personnes ne consultent leurs emails qu\'une fois par semaine. D\'autres peuvent être en vacances ou absents pendant de longues périodes. Après un certain temps, vous pouvez les relancer par téléphone, ou éventuellement par email.</p>
<h5>Comment enregistrer un échange avec notre SEL ? (Compte central)</h5>
<p>Exemples: des travaux du comité des fêtes et d\'autres tâches pour l\'association.<br />
Contactez un responsable de votre communauté et demandez lui le nom ou le numéro de votre compte central. Choisissez le compte central comme partenaire dans l\'échange. Un-e responsable de votre SEL confirmera l\'échange par la suite.&nbsp;</p>
<h5>Est-ce que je peux modifier un échange déjà saisi?</h5>
<p>Oui, si votre partenaire dans l\'échange n\'a pas encore confirmé l\'échange. Vous pouvez même le supprimer.</p>
<h5>Que faire en cas d\'échanges doublons ?</h5>
<p>Si l\'échange n\'a pas encore été confirmé, la personne qui a saisi l\'échange peut le supprimer. Si l\'échange est confirmé, vous pouvez saisir un échange de "correction" (avec le même nombre de unités dans le sens inverse avec la même personne). Mettez dans la description: "correction de l\'échange "X" le "X"". Donc, les deux échanges s\'annulent.</p>
<h3>Contributions</h3>
<h5>Qu\'est-ce-qu\'une Contribution ?</h5>
<p>Partant du principe que si chaque membre contribue à son association, il&nbsp;y&nbsp;a moins besoin d\'impôts (Contributions SELidaire), nous affichons dans la partie "Contributions" du site les petits coups de mains nécessaires au fonctionnement du SEL. Portez-vous volontaire pour ces tâches en contactant la personne "Propriétaire de la tâche". Vous serez crédité d\'un point "Contributions" pour chaque tâche accomplie.</p>
<h3>Imprimer une liste</h3>
<h5>Comment imprimer une liste?</h5>
<p>Cliquez sur l\'icône "imprimante" qui se trouve en bas des pages. Toutes les pages n\'ont pas cette possibilité. Conseil: Regardez l\'aperçu avant d\'imprimer, car les listes peuvent être longues. Pensez à limiter la consommation de papier en utilisant le site.</p>
<h3>Site</h3>
<h5>Je n\'ai pas accès aux informations</h5>
<p>Seuls les membres ayant saisi leur numéro de membre et leur mot de passe peuvent voir les détails des annonces et les adresses des membres.</p>
<h5>Pourquoi avoir fait un nouveau site?</h5>
<p>Avec l\'augmentation importante du nombre des membres, la saisie des échanges et la répartition des tâches est devenue nécessaire. Le site vise également à :</p>
<ul>
<li>favoriser les échanges</li>
<li>renforcer les liens entre les membres</li>
<li>augmenter la transparence</li>
<li>baisser la contribution solidaire (impôt).</li>
</ul>
<h3>FAQ</h3>
<h5>D\'autres questions sur la manière d\'utiliser le site de votre communauté&nbsp;?</h5>
<p>Contactez un(e) responsable de votre communauté</p>
<h5>Qui a créé l\'outil de base de Community Forge pour gérer les SELs?</h5>
<p><a href="mailto:matslats@gmail.com">Matthew Slater, un informaticien</a>&nbsp;et&nbsp;<a href="mailto:timcarouge@gmail.com">Tim Anderson, un membre d\'un SEL</a>.<br />
Notre premier installation était le <a href="http://www.seldulac.ch"> SELduLac </a> à Genève.<br />
Avec l\'aide d\'une équipe de bénévoles, nous mettons nos compétences&nbsp;à la disposition des autres SELs &nbsp;pour favoriser, grâce à cette&nbsp;plateforme d\'échanges, le développement de plus en plus de SELs.</p>
<p>Pour toute question technique, rendez-vous sur le <a href="http://helpdesk.communityforge.net/fr/">site du centre d\'entraide/helpdesk</a>.&nbsp;</p>',
          'format' => 'full_html',
        ),
      ),
    ),
    'path' => array (
      'alias' => 'faq',
    ),
    'menu' => array (
      'link_title' => t('FAQ'),
      'description' => '',
      'menu_name' => 'secondary-menu',
      'module' => 'menu',
      'weight' => '2',
      'enabled' => true,
    ),
  );

  $nodes[] = array(
    'type' => 'page',
    'uid' => '1',
    'status' => '1',
    'comment' => '0',
    'sticky' => '0',
    'format' => 'full_html',
    'language' => $lang,
    'title' => t('About LETS'),
    'body' => array(
      'fr' => array(
        0 => array(
          'value' => '<h3><strong>Explique-moi comment fonctionne un Système d&apos;Echange Local</strong></h3>
<p><strong><em>Unité d&apos;échange</em> </strong></p>
<p>L&apos;unité d&apos;échange, le "grain", par exemple, permet de mesurer les échanges entre adhérents.</p>
<p><strong><em>Mais c&apos;est du troc !</em></strong></p>
<p>Pas du tout. Dans le troc, deux personnes échangent au même moment deux choses qui ont à peu près la même valeur. Dans le SEL, les "grains" permettent de transférer, entre différentes personnes et à différents moments, des services, des savoirs ou, dans certains SEL, des biens qui ont des valeurs différentes.</p>
<p><strong><em>Les "grains" et les Euros, c&apos;est pareil ?</em> </strong></p>
<p>Non, car, pour dépenser des Euros, il faut d&apos;abord en posséder. Alors qu&apos;avec un compte à zéro je peux échanger tout de suite.</p>
<p>Non, parce que les "grains" ne sont pas convertibles en Euros, ni les Euros en "grains".</p>
<p>Non, car les "grains" ne sont pas utilisables en dehors des systèmes d&apos;échanges locaux.</p>
<p>Non, car les "grains" ne sont pas capitalisables, ne produisent pas d&apos;intérêts et n&apos;engendre aucune spéculation.</p>
<p><strong><em>Qui fixe la valeur ?</em> </strong></p>
<p>Notre étalon de départ se mesure en temps : une heure = 60 "grains" dans notre exemple. Toutefois, les adhérents sont libres de fixer la valeur qu&apos;ils veulent suivant le plaisir, la difficulté ou la pénibilité représentée par une tâche ou selon leur expérience. Si c&apos;est cette dernière formule qui est choisie, veillez à déterminer la valeur, avant de commencer le service pour qu&apos;il n&apos;y ait pas de malentendu. &nbsp;Lorsqu&apos;on échange des objets, les deux partenaires d&apos;échanges conviennent ensemble de sa valeur.</p>
<p><strong><em>Mais, tous ces comptes, c&apos;est compliqué !</em></strong></p>
<p>Rien n&apos;empêche ceux qui avaient l&apos;habitude de rendre un service gratuit de le faire, une fois ou l&apos;autre, ou en partie.</p>
<p>L&apos;expérience prouve que le SEL provoque la rencontre et génère le don.</p>
<p><strong><em>Ce n&apos;est pas grave d&apos;avoir un compte SEL en négatif ?</em> </strong></p>
<p>Pas du tout. Chacun commence avec un compte à zéro. Si j&apos;ai versé 90 "grains"&nbsp;à Marc qui est venu m&apos;aider à désherber mon jardin, son compte devient positif et le mien, négatif, remontera au fur et à mesure que je garderai les enfants de Pierre. Ainsi, dans un SEL, il y a nécessairement des adhérents qui ont un compte négatif, et d&apos;autres un compte positif. La somme de tous les montants de tous les comptes est égale à zéro.</p>
<p><strong><em>On peut rester dans le négatif indéfiniment ?</em> </strong></p>
<p>Les limites sont fixés par votre communauté, par exemple&nbsp;entre -500 et +500 "grains". Si un adhérent atteint cette limite, on lui demande de veiller à rééquilibrer ses échanges.</p>
<p><strong><em>Qu&apos;est-ce qui m&apos;empêche de partir avec un compte négatif ?</em> </strong></p>
<p>Un débit constitue un engagement à rendre au groupe des services, ou des savoirs. Or, dans le SEL, entre les personnes qui se rencontrent et font connaissance naît la confiance en même temps que l&apos;engagement moral.</p>
<p>En pratique, ça suffit pour que ce genre de comportement irrespectueux soit très rare.</p>
<p><strong><em>Quelle garantie a-t-on sur la qualité des biens ou des services proposés ?</em></strong></p>
<p>Aucune. C&apos;est aux adhérents de discuter, pour savoir si l&apos;un a le niveau de qualification que souhaite l&apos;autre afin de se mettre d&apos;accord avant l&apos;échange. Il n&apos;existe pas de solution toute faite, ça passe par la discussion et la confiance. En cas de problème, votre communauté peut peut-être proposer un(e) médiateur(trice) peut aider l&apos;un et l&apos;autre à trouver une solution équitable.</p>
<p><strong><em>Mais c&apos;est du travail au noir ?</em></strong></p>
<p>Non, il s&apos;agit d&apos;une entraide entre adhérents, pour des coups de main « ponctuels, non répétitifs et de courte durée ». &nbsp;De plus, si Marie demande à Bernard de l&apos;aider à retapisser son appartement parce que ses fins de mois sont difficiles, c&apos;est un autre artisan ou commerçant qui bénéficiera de l&apos;argent économisé par Marie.</p>
<p>La pratique montre qu&apos;énormément d&apos;échanges qui n&apos;auraient pas pu voir le jour dans le cadre classique du marché se font au sein des SEL.</p>
<p>Plus il y a de convivialité et de rencontres, plus il y a d&apos;échanges, plus se créent des liens de proximité, entraînant de nouveaux échanges.</p>
<p><strong><em>Mais moi je n&apos;ai rien à proposer !</em> </strong></p>
<p>C&apos;est ce que dit tout le monde !</p>
<p>Ce que vous pouvez proposer ne vous paraît souvent pas intéressant parce qu&apos;il n&apos;est habituellement pas compté comme travail rétribué en Euros.</p>
<p>Pourtant chacun possède une richesse à donner aux autres : faire de la pâtisserie, du bricolage, proposer les noix de son jardin, raconter des histoires aux enfants, écouter celui qui a un gros coup de cafard.</p>
<p>Tout le monde, enfants, retraités, chômeurs, a quelque chose à proposer.</p>
<p>Il suffit d&apos;être à l&apos;écoute de ses différences. C&apos;est fou ce qu&apos;on peut se découvrir alors comme nouveaux talents.</p>
<h3><strong>A propos des SELs :</strong>&nbsp;</h3>
<ul dir="ltr">
	<li><a href="http://www.lets-linkup.com/" target="_blank">lets-linkup.com</a></li>
</ul>
<p class="rteindent1">Le site propose la liste des SELs présents dans chaque pays. Incomplet mais utile.</p>
<ul dir="ltr">
	<li><a href="http://www.sel-lets.be/" target="_blank">Sel-Lets.be</a></li>
</ul>
<p class="rteindent1">Nomenclature et guide des sites de Sel en Belgique francophone.</p>
<ul dir="ltr">
	<li><a href="http://www.letsvlaanderen.be" target="_blank">letsvlaanderen.be</a></li>
</ul>
<p class="rteindent1">Les SELS en Belgique&nbsp;<span style="line-height: 20.8px;">&nbsp;néérlandophones.</span></p>
<ul dir="ltr">
	<li><a href="http://route-des-sel.org/" target="_blank">La route des SELs</a></li>
</ul>
<p class="rteindent1">Site créé pour facilite les échanges et hébergements entre Sélistes de tous horizons...</p>
<ul dir="ltr">
	<li><a href="http://selidaire.org/" target="_blank">selidaire.org</a></li>
</ul>
<p class="rteindent1">Informations générales sur le fonctionnement des SELs, forums, ...</p>
<ul dir="ltr">
	<li><a href="http://transversel.org/" target="_blank">Transversel.org</a></li>
</ul>
<p class="rteindent1">Information à propos des SELs. A jour, le plus vivant en français.<span style="line-height: 1.6em;">.</span></p>
<p><u>SELs en Suisse</u> :</p>
<ul dir="ltr">
	<li><a href="http://www.sel-suisse.ch/" target="_blank">Sel-Suisse.ch</a></li>
</ul>
<p class="rteindent1">Portail des SELs suisses, &nbsp;incomplet mais utile.</p>
<ul dir="ltr">
	<li><a href="http://enlien.ch/" target="_blank">EnLien.ch</a></li>
</ul>
<p class="rteindent1">Plateforme de 12 SELs en Suisse romande.</p>
<ul dir="ltr">
	<li><a href="http://www.tauschnetz.ch/" target="_blank">Tauschnetz.ch</a></li>
</ul>
<p class="rteindent1">La plupart des SELs de Suisse alémanique.</p>
page_lets.txtOuvrir
3 sur 5 éléments
page_commit.txtpage_home.txtpage_lets.txtpage_share.txtpage_start.txtAffichage de page_lets.txt en cours...<h3><strong>Explique-moi comment fonctionne un Système d&apos;Echange Local</strong></h3>
<p><strong><em>Unité d&apos;échange</em> </strong></p>
<p>L&apos;unité d&apos;échange, le "grain", par exemple, permet de mesurer les échanges entre adhérents.</p>
<p><strong><em>Mais c&apos;est du troc !</em></strong></p>
<p>Pas du tout. Dans le troc, deux personnes échangent au même moment deux choses qui ont à peu près la même valeur. Dans le SEL, les "grains" permettent de transférer, entre différentes personnes et à différents moments, des services, des savoirs ou, dans certains SEL, des biens qui ont des valeurs différentes.</p>
<p><strong><em>Les "grains" et les Euros, c&apos;est pareil ?</em> </strong></p>
<p>Non, car, pour dépenser des Euros, il faut d&apos;abord en posséder. Alors qu&apos;avec un compte à zéro je peux échanger tout de suite.</p>
<p>Non, parce que les "grains" ne sont pas convertibles en Euros, ni les Euros en "grains".</p>
<p>Non, car les "grains" ne sont pas utilisables en dehors des systèmes d&apos;échanges locaux.</p>
<p>Non, car les "grains" ne sont pas capitalisables, ne produisent pas d&apos;intérêts et n&apos;engendre aucune spéculation.</p>
<p><strong><em>Qui fixe la valeur ?</em> </strong></p>
<p>Notre étalon de départ se mesure en temps : une heure = 60 "grains" dans notre exemple. Toutefois, les adhérents sont libres de fixer la valeur qu&apos;ils veulent suivant le plaisir, la difficulté ou la pénibilité représentée par une tâche ou selon leur expérience. Si c&apos;est cette dernière formule qui est choisie, veillez à déterminer la valeur, avant de commencer le service pour qu&apos;il n&apos;y ait pas de malentendu. &nbsp;Lorsqu&apos;on échange des objets, les deux partenaires d&apos;échanges conviennent ensemble de sa valeur.</p>
<p><strong><em>Mais, tous ces comptes, c&apos;est compliqué !</em></strong></p>
<p>Rien n&apos;empêche ceux qui avaient l&apos;habitude de rendre un service gratuit de le faire, une fois ou l&apos;autre, ou en partie.</p>
<p>L&apos;expérience prouve que le SEL provoque la rencontre et génère le don.</p>
<p><strong><em>Ce n&apos;est pas grave d&apos;avoir un compte SEL en négatif ?</em> </strong></p>
<p>Pas du tout. Chacun commence avec un compte à zéro. Si j&apos;ai versé 90 "grains"&nbsp;à Marc qui est venu m&apos;aider à désherber mon jardin, son compte devient positif et le mien, négatif, remontera au fur et à mesure que je garderai les enfants de Pierre. Ainsi, dans un SEL, il y a nécessairement des adhérents qui ont un compte négatif, et d&apos;autres un compte positif. La somme de tous les montants de tous les comptes est égale à zéro.</p>
<p><strong><em>On peut rester dans le négatif indéfiniment ?</em> </strong></p>
<p>Les limites sont fixés par votre communauté, par exemple&nbsp;entre -500 et +500 "grains". Si un adhérent atteint cette limite, on lui demande de veiller à rééquilibrer ses échanges.</p>
<p><strong><em>Qu&apos;est-ce qui m&apos;empêche de partir avec un compte négatif ?</em> </strong></p>
<p>Un débit constitue un engagement à rendre au groupe des services, ou des savoirs. Or, dans le SEL, entre les personnes qui se rencontrent et font connaissance naît la confiance en même temps que l&apos;engagement moral.</p>
<p>En pratique, ça suffit pour que ce genre de comportement irrespectueux soit très rare.</p>
<p><strong><em>Quelle garantie a-t-on sur la qualité des biens ou des services proposés ?</em></strong></p>
<p>Aucune. C&apos;est aux adhérents de discuter, pour savoir si l&apos;un a le niveau de qualification que souhaite l&apos;autre afin de se mettre d&apos;accord avant l&apos;échange. Il n&apos;existe pas de solution toute faite, ça passe par la discussion et la confiance. En cas de problème, votre communauté peut peut-être proposer un(e) médiateur(trice) peut aider l&apos;un et l&apos;autre à trouver une solution équitable.</p>
<p><strong><em>Mais c&apos;est du travail au noir ?</em></strong></p>
<p>Non, il s&apos;agit d&apos;une entraide entre adhérents, pour des coups de main « ponctuels, non répétitifs et de courte durée ». &nbsp;De plus, si Marie demande à Bernard de l&apos;aider à retapisser son appartement parce que ses fins de mois sont difficiles, c&apos;est un autre artisan ou commerçant qui bénéficiera de l&apos;argent économisé par Marie.</p>
<p>La pratique montre qu&apos;énormément d&apos;échanges qui n&apos;auraient pas pu voir le jour dans le cadre classique du marché se font au sein des SEL.</p>
<p>Plus il y a de convivialité et de rencontres, plus il y a d&apos;échanges, plus se créent des liens de proximité, entraînant de nouveaux échanges.</p>
<p><strong><em>Mais moi je n&apos;ai rien à proposer !</em> </strong></p>
<p>C&apos;est ce que dit tout le monde !</p>
<p>Ce que vous pouvez proposer ne vous paraît souvent pas intéressant parce qu&apos;il n&apos;est habituellement pas compté comme travail rétribué en Euros.</p>
<p>Pourtant chacun possède une richesse à donner aux autres : faire de la pâtisserie, du bricolage, proposer les noix de son jardin, raconter des histoires aux enfants, écouter celui qui a un gros coup de cafard.</p>
<p>Tout le monde, enfants, retraités, chômeurs, a quelque chose à proposer.</p>
<p>Il suffit d&apos;être à l&apos;écoute de ses différences. C&apos;est fou ce qu&apos;on peut se découvrir alors comme nouveaux talents.</p>
<h3><strong>A propos des SELs :</strong>&nbsp;</h3>
<ul dir="ltr">
	<li><a href="http://www.lets-linkup.com/" target="_blank">lets-linkup.com</a></li>
</ul>
<p class="rteindent1">Le site propose la liste des SELs présents dans chaque pays. Incomplet mais utile.</p>
<ul dir="ltr">
	<li><a href="http://www.sel-lets.be/" target="_blank">Sel-Lets.be</a></li>
</ul>
<p class="rteindent1">Nomenclature et guide des sites de Sel en Belgique francophone.</p>
<ul dir="ltr">
	<li><a href="http://www.letsvlaanderen.be" target="_blank">letsvlaanderen.be</a></li>
</ul>
<p class="rteindent1">Les SELS en Belgique&nbsp;<span style="line-height: 20.8px;">&nbsp;néérlandophones.</span></p>
<ul dir="ltr">
	<li><a href="http://route-des-sel.org/" target="_blank">La route des SELs</a></li>
</ul>
<p class="rteindent1">Site créé pour facilite les échanges et hébergements entre Sélistes de tous horizons...</p>
<ul dir="ltr">
	<li><a href="http://selidaire.org/" target="_blank">selidaire.org</a></li>
</ul>
<p class="rteindent1">Informations générales sur le fonctionnement des SELs, forums, ...</p>
<ul dir="ltr">
	<li><a href="http://transversel.org/" target="_blank">Transversel.org</a></li>
</ul>
<p class="rteindent1">Information à propos des SELs. A jour, le plus vivant en français.<span style="line-height: 1.6em;">.</span></p>
<p><u>SELs en Suisse</u> :</p>
<ul dir="ltr">
	<li><a href="http://www.sel-suisse.ch/" target="_blank">Sel-Suisse.ch</a></li>
</ul>
<p class="rteindent1">Portail des SELs suisses, &nbsp;incomplet mais utile.</p>
<ul dir="ltr">
	<li><a href="http://enlien.ch/" target="_blank">EnLien.ch</a></li>
</ul>
<p class="rteindent1">Plateforme de 12 SELs en Suisse romande.</p>
<ul dir="ltr">
	<li><a href="http://www.tauschnetz.ch/" target="_blank">Tauschnetz.ch</a></li>
</ul>
<p class="rteindent1">La plupart des SELs de Suisse alémanique.</p>',
          'format' => 'full_html',
        )
      )
    ),
    'path' => array (
      'alias' => 'lets',
    ),
    'menu' => array (
      'link_title' => t('About LETS'),
      'description' => '',
      'menu_name' => 'secondary-menu',
      'module' => 'menu',
      'weight' => '3',
      'enabled' => true,
    )
  );

  //special node is scraped from cforge site so it's at least up to date when the site is created
  $available_langs = array('fr', 'en');//prefixes available on cforge.net for step-by-step page
  if ($lang == LANGUAGE_NONE || !in_array($lang, $available_langs)) $lang = 'en';

  ini_set('allow_url_fopen', TRUE);
  $url = "http://helpdesk.communityforge.net/$lang/step-by-step";
  $page = file_get_contents($url);
  if($page) {
    //remove the characters before the start
    $page = substr($page, strpos($page, '<!--cfscrape-->') + strlen('<!--cfscrape-->'));
    //remove the characters after the end
    $page = substr($page, 0, strpos($page, '<!--/cfscrape-->'));
    //this is nasty, but for the javascript fieldsets to work, we have to remove a linebreak which was inserted by the scraping
    $page = str_replace("/legend>\n", "/legend>", $page);

    $nodes[] = array(
      'type' => 'story',
      'uid' => '1',
      'status' => '1',
      'comment' => '0',
      'sticky' => '0',
      'format' => 'full_html',
      'language' => $lang,
      'title' => t('Step by step guide to setting up your site'),
      'body' => array (
        $lang => array (
          0 => array (
            'value' => $page,
            'format' => 'full_html',
            'summary' => substr($page, 0, strpos($page, '</p>'))
          )
        )
      ),
      'path' => array (
        'alias' => 'step-by-step',
      ),
    );
  }
  else {
    watchdog('installation', 'Unable to to retrieve: @url', array('@url' => $url));
    drupal_set_message(t('Unable to to retrieve: @url', array('@url' => $url)));
  }
  return $nodes;
}
